<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="sub-page-detail">
            <el-table
                :element-loading-background="loadingColor"
                v-loading="loading"
                height="calc(100% - 20PX)"
                align="center"
                :data="tableData"
                class="dialog_table"
                :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}"
            >
                <el-table-column
                    type="index"
                    label="序号"
                    align="center"
                    width="80"
                >
                </el-table-column>
                <el-table-column prop="projectName" label="项目名称">
                    <el-table-column prop="projectName" label="总计">
                        <template v-slot="{row}">
                            <div
                                style="cursor: pointer"
                                @click="
                                    handleDetail(
                                        'projectSubIndexLibrary',
                                        row.projectId,
                                        row.projectName +
                                            '·截至本月各项核心指标完成情况'
                                    )
                                "
                            >
                                {{ row.projectName }}
                            </div>
                        </template>
                    </el-table-column>
                </el-table-column>
                <el-table-column
                    prop="totalYearNum"
                    :label="`年度核心指标总数`"
                    width="160"
                >
                    <el-table-column
                        prop="totalYearNum"
                        :label="sum1 + ''"
                        width="240"
                    ></el-table-column>
                </el-table-column>
                <el-table-column
                    prop="finishYearNum"
                    :label="`累计完成年度核心指标个数`"
                    width="160"
                >
                    <el-table-column
                        prop="finishYearNum"
                        :label="sum2 + ''"
                        width="240"
                    ></el-table-column>
                </el-table-column>
                <el-table-column
                    prop="finishYearRate"
                    :label="`完成率`"
                    width="160"
                >
                    <el-table-column
                        prop="finishYearRate"
                        :label="sum3"
                        width="240"
                    >
                        <template v-slot="{row}">
                            {{ row.finishYearRate }}%
                        </template>
                    </el-table-column>
                </el-table-column>
            </el-table>
            <!-- <div style="font-size: 16PX;">备注：根据达标率进行排名取前20%的为优秀，50%-80%为良好，其余为一般。</div> -->
        </div>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView.js'
export default {
    name: 'monthPlan',
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            origin: [],
            sum1: 0,
            sum2: 0,
            sum3: '',
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.loadData()
        this.$bus.$on('changeDate', (searchDate) => {
            this.loadData()
        })
    },
    created() {
        this.$emit('searchDateChange')
    },
    methods: {
        getSummaries(param) {
            const {columns, data} = param
            const sums = []
            columns.forEach((column, index) => {
                if (index === 1 || index === 0 || index === 8) {
                    sums[index] = index === 1 ? '总计' : ''
                    return
                }
                const values = data.map((item) => Number(item[column.property]))
                if (!values.every((value) => isNaN(value))) {
                    sums[index] = values.reduce((prev, curr) => {
                        const value = Number(curr)
                        if (!isNaN(value)) {
                            return prev + curr
                        } else {
                            return prev
                        }
                    }, 0)
                }
                if (index === 7) {
                    sums[index] = ((sums[5] / sums[4]) * 100).toFixed(2) + '%'
                }
            })
            return sums
        },
        handleDetail(comp, id, title) {
            this.$router.push({
                path: '/DetailComponent',
                name: 'DetailComponent',
                query: {
                    comp,
                    projectId: id,
                    title,
                },
            })
        },
        // 改革品牌榜
        loadData() {
            this.loading = true
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            apiList.getIndexPieChartData(data, (res) => {
                if (res.indexVoList) {
                    this.tableData = res.indexVoList
                    this.sum1 = 0
                    this.sum2 = 0
                    this.sum3 = ''
                    res.indexVoList.forEach((item) => {
                        this.sum1 += item.totalYearNum
                        this.sum2 += item.finishYearNum
                    })
                    this.sum3 = ((this.sum2 / this.sum1) * 100).toFixed(2) + '%'
                }
                this.loading = false
            })
        },
        // 计算优良一般比例 排名的
        // 排名的20%    优
        // 排名的30% 良
        // 排名的50%   一般
        mathTargetIndexFinish() {
            let targetSn = 0
            this.origin.forEach((item) => {
                if (targetSn < item.targetSn) {
                    targetSn = item.targetSn
                }
            })
            let level1 = targetSn * 0.2
            let level2 = targetSn * 0.5

            let level1Num = 0
            let level2Num = 0
            let level3Num = 0
            this.origin.forEach((item) => {
                if (item.targetSn <= level1) {
                    item.type = 1
                } else if (item.targetSn <= level2) {
                    item.type = 2
                } else {
                    item.type = 3
                }
            })
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/.el-table--border th.el-table__cell {
    border-bottom: 1px solid #01215a;
}

/deep/.el-table--border th {
    border: 1px solid #01215a !important;

    &:last-child {
        border: none !important;
    }
}

/deep/.el-table--border td {
    border-right: 0px solid #01215a !important;
}

/deep/.el-table--border th.el-table__cell.gutter:last-of-type {
    border: none;
}

/deep/.el-table--group,
.el-table--border {
    border: none;
}

/deep/.el-table--border::after {
    background: none;
}

/deep/.el-table__footer-wrapper tbody td.el-table__cell {
    text-align: center;
    background-color: #072d62;
    border-top: none;
}

/deep/.gutter {
    background-color: #072d62 !important;
}

// /deep/.el-table--scrollable-y .el-table__body-wrapper {
//     height: 710px !important;
// }

.sub-page-detail {
    width: 100%;

    * {
        font-size: 18PX !important;
    }
}

.sub-page-detail {
    margin: 0 auto;
}

.column-item-rotate {
    display: inline-block;
    transform: rotateX(180deg);
}

.cqlt-icon-arrow {
    font-size: 18PX;
}

.column-trend-icon-1 {
    color: #59c06c;
    text-shadow: #59c06c 1PX 0 12PX;
}

.column-trend-icon-2 {
    color: #fe3b30;
    text-shadow: #fe3b30 1PX 0 12PX;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
